==> haskell-email-validate-2.3.2.11-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: email-validate
version: 2.3.2.11
id: email-validate-2.3.2.11-9jmfd3S2lkn4Ye96H6JHzg
key: email-validate-2.3.2.11-9jmfd3S2lkn4Ye96H6JHzg
license: BSD-3-Clause
maintainer: George Pollard <porges@porg.es>
author: George Pollard <porges@porg.es>
stability: experimental
homepage: https://github.com/Porges/email-validate-hs
synopsis: Email address validation
description:
    Validating an email address string against RFC 5322
category: Text
abi: 828cec6826844a74431f60bdd500b277
exposed: True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate
import-dirs: /usr/lib/ghc-8.6.5/site-local/email-validate-2.3.2.11
library-dirs: /usr/lib/ghc-8.6.5/site-local/email-validate-2.3.2.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/email-validate-2.3.2.11
hs-libraries: HSemail-validate-2.3.2.11-9jmfd3S2lkn4Ye96H6JHzg
depends:
    attoparsec-0.13.2.2-IYmscZi60PM1VHlw2sOR1C base-4.12.0.0
    bytestring-0.10.8.2 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-email-validate/html/email-validate.haddock
haddock-html: /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-email-validate-2.3.2.11-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: email-validate
version: 2.3.2.11
id: email-validate-2.3.2.11-BhozeVMKcVFAePgl9Y5ZrZ
key: email-validate-2.3.2.11-BhozeVMKcVFAePgl9Y5ZrZ
license: BSD-3-Clause
maintainer: George Pollard <porges@porg.es>
author: George Pollard <porges@porg.es>
stability: experimental
homepage: https://github.com/Porges/email-validate-hs
synopsis: Email address validation
description:
    Validating an email address string against RFC 5322
category: Text
abi: 007fb7c8ca6df4258f20e3e322538862
exposed: True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate
import-dirs: /usr/lib/ghc-8.6.5/site-local/email-validate-2.3.2.11
library-dirs: /usr/lib/ghc-8.6.5/site-local/email-validate-2.3.2.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/email-validate-2.3.2.11
hs-libraries: HSemail-validate-2.3.2.11-BhozeVMKcVFAePgl9Y5ZrZ
depends:
    attoparsec-0.13.2.2-EdUct2wsQri8X0bjC24wTV base-4.12.0.0
    bytestring-0.10.8.2 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-email-validate/html/email-validate.haddock
haddock-html: /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
